@@ -4,15 +4,19 @@ from ververser.game_window import GameWindow
 
 from pyglet.gl import glClearColor
 
+import random
+
+
+def _r() -> float:
+    return random.uniform(0, 1)
 
 class Game:
 
     def __init__( self, game_window : GameWindow ):
         self.game_window = game_window
-        glClearColor( 255 / 255, 10 / 255, 10 / 255, 1.0 )  # red, green, blue, and alpha(transparency)
 
     def update( self, dt ):
-        ...
+        glClearColor( 1, 1, 1, 1.0 )
 
     def draw( self ):
         ...
