@@ -25,7 +25,7 @@ class ReloadingAsset:
             self.asset = self.f_load_asset( asset_path )
         except Exception as e :
             logging.error( f'Encountered an error during loading of asset from file "{asset_path}"' )
-            logging.error( e )
+            logging.exception( e )
             self.reload_status = ReloadStatus.FAILED
             return self.reload_status
         self.reload_status =  ReloadStatus.RELOADED
